@@ -1,11 +1,13 @@
+use core::iter::FusedIterator;
+
 use crate::array;
 
 /// An iterator that yields overlapping chunks of `N` elements of `T` at a time.
 ///
-/// This struct is created by the [`windows`][crate::IterMore::windows] method
-/// on iterators.
+/// This struct is created by the
+/// [`array_windows`][crate::Itermore::array_windows] method on iterators.
 #[derive(Debug, Clone)]
-pub struct Windows<I, T, const N: usize>
+pub struct ArrayWindows<I, T, const N: usize>
 where
     I: Iterator<Item = T>,
 {
@@ -13,17 +15,17 @@ where
     last: Option<[T; N]>,
 }
 
-impl<I, T, const N: usize> Windows<I, T, N>
+impl<I, T, const N: usize> ArrayWindows<I, T, N>
 where
     I: Iterator<Item = T>,
 {
     #[inline]
-    pub fn new(iter: I) -> Self {
+    pub(crate) fn new(iter: I) -> Self {
         Self { iter, last: None }
     }
 }
 
-impl<I, T, const N: usize> Iterator for Windows<I, T, N>
+impl<I, T, const N: usize> Iterator for ArrayWindows<I, T, N>
 where
     I: Iterator<Item = T>,
     T: Clone,
@@ -50,3 +52,10 @@ where
         }
     }
 }
+
+impl<I, T, const N: usize> FusedIterator for ArrayWindows<I, T, N>
+where
+    I: FusedIterator<Item = T>,
+    T: Clone,
+{
+}
